@@ -260,12 +260,14 @@ CODALAB_ARGUMENTS = [
         help=(
             'Ingest URL for logging exceptions with Sentry. If not provided, Sentry is not used.'
         ),
+        frontend=True,
     ),
     CodalabArg(
         name='sentry_environment',
         help=(
             'Environment for logging exceptions with Sentry. If not provided, Sentry is not used.'
         ),
+        frontend=True,
     ),
     # Bundle Manager
     CodalabArg(
@@ -335,6 +337,31 @@ CODALAB_ARGUMENTS = [
         type=str,
         help='Azure Batch service url for the Azure Batch worker manager',
     ),
+    CodalabArg(
+        name='worker_manager_gcp_project',
+        type=str,
+        help='GCP project for the GCP Batch worker manager',
+    ),
+    CodalabArg(
+        name='worker_manager_gcp_gke_cluster',
+        type=str,
+        help='Name of the GKE cluster for the GCP Batch worker manager',
+    ),
+    CodalabArg(
+        name='worker_manager_gcp_gke_zone',
+        type=str,
+        help='Availability zone of the GKE cluster for the GCP Batch worker manager',
+    ),
+    CodalabArg(
+        name='worker_manager_gcp_credentials_path',
+        type=str,
+        help='Path to the GCP service account json file for the GCP Batch worker manager',
+    ),
+    CodalabArg(
+        name='worker_manager_gcp_cert_path',
+        type=str,
+        help='Path to the generated SSL cert for the GCP Batch worker manager',
+    ),
     CodalabArg(
         name='worker_manager_aws_region',
         type=str,
@@ -913,6 +940,9 @@ class CodalabServiceManager(object):
         if self.args.worker_manager_type == 'azure-batch':
             self.bring_up_service('azure-batch-worker-manager-cpu')
             self.bring_up_service('azure-batch-worker-manager-gpu')
+        elif self.args.worker_manager_type == 'gcp-batch':
+            self.bring_up_service('gcp-batch-worker-manager-cpu')
+            self.bring_up_service('gcp-batch-worker-manager-gpu')
         elif self.args.worker_manager_type == 'aws-batch':
             self.bring_up_service('aws-batch-worker-manager-cpu')
             self.bring_up_service('aws-batch-worker-manager-gpu')
